@@ -147,3 +147,11 @@ class LocalDiskBackendTestCase(unittest.TestCase):
         self.assertTrue(self.backend.exists(src))
         self.backend.unlink('foo/bar/baz')
         self.assertTrue(not self.backend.exists(src))
+
+    def test_overwrite(self):
+        """Overwriting an existing key must not raise exceptions."""
+        src = 'foo/bar/baz/taz'
+        with self.backend.open(src, 'w') as f:
+            f.write("Hello world!")
+        with self.backend.open(src, 'w') as f:
+            f.write("Hello world!")
